@@ -601,6 +601,8 @@ def ensure_annotations(f):
     :class:`EnsureError` if any argument passed to *f* is not of the type specified by the annotation. Also raises
     :class:`EnsureError` if the return value of *f* is not of the type specified by the annotation. Examples:
 
+    .. code-block:: python
+
         from ensure import ensure_annotations
 
         @ensure_annotations
@@ -613,22 +615,34 @@ def ensure_annotations(f):
 
         print(f(1, y=2))
 
-        >>> ensure.EnsureError: 2 is not an instance of <class 'float'>
+        >>> ensure.EnsureError: Argument y to <function f at 0x109b7c710> does not match annotation type <class 'float'>
     """
     from functools import wraps
-    from inspect import getcallargs
     @wraps(f)
     def wrapper(*args, **kwargs):
-        for arg, val in getcallargs(f, *args, **kwargs).items():
-            if arg in f.__annotations__:
-                templ = f.__annotations__[arg]
+        arg_pos = None
+        for arg, templ in f.__annotations__.items():
+            if arg == 'return':
+                continue
+            elif arg in kwargs:
+                value = kwargs[arg]
+            else:
+                if arg_pos is None:
+                    arg_pos = {arg: pos for pos, arg in enumerate(f.__code__.co_varnames)}
+                if arg in arg_pos:
+                    value = args[arg_pos[arg]]
+                else:
+                    continue
+            if not isinstance(value, templ):
                 msg = "Argument {arg} to {f} does not match annotation type {t}"
-                Check(val).is_an(templ).or_raise(EnsureError, msg.format(arg=arg, f=f, t=templ))
+                raise EnsureError(msg.format(arg=arg, f=f, t=templ))
+
         return_val = f(*args, **kwargs)
         if 'return' in f.__annotations__:
             templ = f.__annotations__['return']
-            msg = "Return value of {f} does not match annotation type {t}"
-            Check(return_val).is_an(templ).or_raise(EnsureError, msg.format(f=f, t=templ))
+            if not isinstance(return_val, templ):
+                msg = "Return value of {f} does not match annotation type {t}"
+                raise EnsureError(msg.format(f=f, t=templ))
         return return_val
     return wrapper
 
